@@ -86,7 +86,9 @@ class Progress():
 
     def __save(self):
         """Write progress to a file.
-        """        
+        """       
+        if self.fp == '':
+            return 
         try:
             with open(self.fp, 'w') as configfile:
                 self.cp.write(configfile)
